==> nextcloud-30.0.13.tgz: nextcloud/apps/files_downloadlimit/l10n/da.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Grænse for download af filer",
    "File link share download limit" : "Grænse for download af fillinkdeling",
    "This app allows limiting the number of downloads for external link shares." : "Denne app giver mulighed for at begrænse antallet af downloads for eksterne link delinger.",
    "The minimum limit is 1" : "Minimumsgrænsen er 1",
    "Failed to set download limit" : "Kunne ikke sætte downloadgrænse",
    "Failed to remove download limit" : "Kunne ikke fjerne downloadgrænse",
    "Limit downloads" : "Begræns downloads",
    "Set download limit" : "Indstil downloadgrænse",
    "Setting a new limit will reset the download count" : "Angivelse af en ny grænse vil nulstille download tællingen",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 resterende download tilladt","{count} resterende tilladte downloads"],
    "Failed to set default download limit" : "Kunne ikke sætte standard downloadgrænse",
    "Download limit" : "Downloadgrænse",
    "Configure the default download limit for external shares." : "Konfigurer standard downloadgrænse for eksterne delinger.",
    "Set default download limit" : "Angiv standard downloadgrænse",
    "You have reached the maximum amount of downloads allowed" : "Du har nået det maksimale antal tilladte downloads",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Denne deling har et begrænset antal downloads. Er du sikker på, at du vil starte en ny download?"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.11.tgz: nextcloud/apps/files_downloadlimit/l10n/da.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Grænse for download af filer",
    "File link share download limit" : "Grænse for download af fillinkdeling",
    "This app allows limiting the number of downloads for external link shares." : "Denne app giver mulighed for at begrænse antallet af downloads for eksterne link delinger.",
    "The minimum limit is 1" : "Minimumsgrænsen er 1",
    "Failed to set download limit" : "Kunne ikke sætte downloadgrænse",
    "Failed to remove download limit" : "Kunne ikke fjerne downloadgrænse",
    "Limit downloads" : "Begræns downloads",
    "Set download limit" : "Indstil downloadgrænse",
    "Setting a new limit will reset the download count" : "Angivelse af en ny grænse vil nulstille download tællingen",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 resterende download tilladt","{count} resterende tilladte downloads"],
    "Download limit" : "Downloadgrænse",
    "Configure the default download limit for external shares." : "Konfigurer standard downloadgrænse for eksterne delinger.",
    "Set default download limit" : "Angiv standard downloadgrænse",
    "You have reached the maximum amount of downloads allowed" : "Du har nået det maksimale antal tilladte downloads",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Denne deling har et begrænset antal downloads. Er du sikker på, at du vil starte en ny download?",
    "Failed to set default download limit" : "Kunne ikke sætte standard downloadgrænse"
},
"nplurals=2; plural=(n != 1);");
